summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/certificate_chain.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/certificate_chain.cc b/src/certificate_chain.cc
index f5092690..588676f8 100644
--- a/src/certificate_chain.cc
+++ b/src/certificate_chain.cc
@@ -194,8 +194,8 @@ CertificateChain::CertificateChain (
string leaf_common_name
)
{
- /* Valid for 25 years */
- int const days = 365 * 25;
+ /* Valid for 10 years */
+ int const days = 365 * 10;
auto directory = boost::filesystem::temp_directory_path() / boost::filesystem::unique_path ();
boost::filesystem::create_directories (directory);